@@ -1,45 +1,49 @@
 package Path::Router;
-BEGIN {
-  $Path::Router::AUTHORITY = 'cpan:STEVAN';
-}
-$Path::Router::VERSION = '0.14';
-use Moose;
-# ABSTRACT: A tool for routing paths
-
-use Eval::Closure;
-use File::Spec::Unix ();
-use Try::Tiny;
+our $AUTHORITY = 'cpan:STEVAN';
+$Path::Router::VERSION = '0.15';
+use 5.008;
+use Carp             1.32;
+use Eval::Closure    0.13;
+use File::Spec::Unix 3.40     ();
+use Try::Tiny        0.19;
+use Types::Standard  1.000005 -types;
 
 use Path::Router::Types;
 use Path::Router::Route;
 use Path::Router::Route::Match;
 
-use constant DEBUG => exists $ENV{PATH_ROUTER_DEBUG} ? $ENV{PATH_ROUTER_DEBUG} : 0;
+use Moo              2.000001;
+use namespace::clean 0.23;
+# ABSTRACT: A tool for routing paths
+
+
+use constant         1.24 DEBUG => exists $ENV{PATH_ROUTER_DEBUG} ? $ENV{PATH_ROUTER_DEBUG} : 0;
 
 has 'routes' => (
     is      => 'ro',
-    isa     => 'ArrayRef[Path::Router::Route]',
+    isa     => ArrayRef[InstanceOf['Path::Router::Route']],
     default => sub { [] },
 );
 
 has 'route_class' => (
     is      => 'ro',
-    isa     => 'ClassName',
+    isa     => ClassName,
     default => 'Path::Router::Route',
 );
 
 has 'inline' => (
     is      => 'rw',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
     trigger => sub { $_[0]->clear_match_code }
 );
 
 has 'match_code' => (
-    is         => 'rw',
-    isa        => 'CodeRef',
-    lazy_build => 1,
-    clearer    => 'clear_match_code'
+    is      => 'rw',
+    isa     => CodeRef,
+    lazy    => 1,
+    builder => 1,
+    clearer => 'clear_match_code'
 );
 
 sub _build_match_code {
@@ -174,7 +178,7 @@ sub uri_for {
     my @possible;
     foreach my $route (@{$self->routes}) {
         local $SIG{__DIE__};
-        
+
         my @url;
         my $url = try {
 
@@ -318,9 +322,7 @@ sub uri_for {
     return $found[0][1];
 }
 
-__PACKAGE__->meta->make_immutable;
-
-no Moose; 1;
+1;
 
 __END__
 
@@ -334,7 +336,7 @@ Path::Router - A tool for routing paths
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -487,6 +489,11 @@ Find the path that, when passed to C<< $router->match >>, would produce the
 given arguments.  Returns the path without any leading C</>.  Returns C<undef>
 if no routes match.
 
+=item B<route_class ($classname)>
+
+The class to use for routes.
+Defaults to L<Path::Router::Route>.
+
 =item B<meta>
 
 =back
@@ -504,7 +511,7 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+Stevan Little E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -519,11 +526,11 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
