@@ -1,68 +1,55 @@
 package Path::Router::Route;
-BEGIN {
-  $Path::Router::Route::AUTHORITY = 'cpan:STEVAN';
-}
-$Path::Router::Route::VERSION = '0.14';
-use Moose;
+our $AUTHORITY = 'cpan:STEVAN';
+$Path::Router::Route::VERSION = '0.15';
+use B;
+use Carp                1.32     qw(cluck);
+use Clone::PP           1.04     ();
+use Path::Router::Types          qw(PathRouterRouteValidationMap);
+use Types::Standard     1.000005 -types;
+
+use Moo                 2.000001;
+use namespace::clean    0.23;
 # ABSTRACT: An object to represent a route
 
-use B;
-use Carp qw(cluck);
-use Path::Router::Types;
-
-with 'MooseX::Clone';
 
 has 'path'  => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1
 );
 
 has 'defaults' => (
-    traits    => [ 'Copy' ],
     is        => 'ro',
-    isa       => 'HashRef',
+    isa       => HashRef,
     default   => sub { {} },
-    predicate => {
-        'has_defaults' => sub {
-            scalar keys %{(shift)->{defaults}}
-        }
-    }
+    predicate => 1,
 );
 
 has 'validations' => (
-    traits    => [ 'Copy' ],
     is        => 'ro',
-    isa       => 'Path::Router::Route::ValidationMap',
+    isa       => PathRouterRouteValidationMap,
     coerce    => 1,
     default   => sub { {} },
-    predicate => {
-        'has_validations' => sub {
-            scalar keys %{(shift)->{validations}}
-        }
-    }
+    predicate => 1,
 );
 
 has 'components' => (
-    traits  => [ 'NoClone' ],
     is      => 'ro',
-    isa     => 'ArrayRef[Str]',
+    isa     => ArrayRef[Str],
     lazy    => 1,
     default => sub { [ grep {defined && length} split '/' => (shift)->path ] }
 );
 
 has 'length' => (
-    traits  => [ 'NoClone' ],
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     lazy    => 1,
     default => sub { scalar @{(shift)->components} },
 );
 
 has 'length_without_optionals' => (
-    traits  => [ 'NoClone' ],
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     lazy    => 1,
     default => sub {
         scalar grep { ! $_[0]->is_component_optional($_) }
@@ -71,17 +58,17 @@ has 'length_without_optionals' => (
 );
 
 has 'required_variable_component_names' => (
-    traits     => [ 'NoClone' ],
-    is         => 'ro',
-    isa        => 'ArrayRef[Str]',
-    lazy_build => 1,
+    is      => 'ro',
+    isa     => ArrayRef[Str],
+    lazy    => 1,
+    builder => 1,
 );
 
 has 'optional_variable_component_names' => (
-    traits     => [ 'NoClone' ],
-    is         => 'ro',
-    isa        => 'ArrayRef[Str]',
-    lazy_build => 1,
+    is      => 'ro',
+    isa     => ArrayRef[Str],
+    lazy    => 1,
+    builder => 1,
 );
 
 has 'target' => (
@@ -89,7 +76,7 @@ has 'target' => (
     # assume cloning of this is not
     # what you would want
     is        => 'ro',
-    isa       => 'Any',
+    isa       => Any,
     predicate => 'has_target'
 );
 
@@ -239,9 +226,11 @@ sub generate_match_code {
 
     push @code, (
         '#line ' . __LINE__ . ' "' . __FILE__ . '"',
-        'print STDERR "Attempting to match ' . $self->path . ' against $path"',
+        'printf STDERR "Attempting to match \"' . $self->path . '\" against \"$path\""',
             'if Path::Router::DEBUG();',
-        'print STDERR "   regexp is " . ' . B::perlstring($regexp),
+        'print STDERR " regexp is " . ' . B::perlstring($regexp),
+            'if Path::Router::DEBUG();',
+        'print STDERR "\n"',
             'if Path::Router::DEBUG();',
         'if ($path =~ /^' . $regexp . '$/) {',
             '# ' . $self->path,
@@ -323,9 +312,22 @@ sub generate_match_code {
     return @code;
 }
 
-__PACKAGE__->meta->make_immutable;
+sub clone {
+    my $self = shift;
+    my %new_args = map {$_ => Clone::PP::clone($self->$_)} qw(path target);
 
-no Moose; 1;
+    if ($self->has_defaults) {
+        $new_args{defaults} = \%{$self->defaults};
+    }
+
+    if ($self->has_validations) {
+        $new_args{validations} = \%{$self->validations};
+    }
+
+    return ref($self)->new({ %new_args, @_ });
+}
+
+1;
 
 __END__
 
@@ -339,7 +341,7 @@ Path::Router::Route - An object to represent a route
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -354,6 +356,8 @@ introspect them.
 
 =item B<new (path => $path, ?%options)>
 
+=item B<clone>
+
 =item B<path>
 
 =item B<target>
@@ -422,7 +426,7 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+Stevan Little E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -437,11 +441,11 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
