@@ -1,24 +1,24 @@
 package Path::Router::Route::Match;
-BEGIN {
-  $Path::Router::Route::Match::AUTHORITY = 'cpan:STEVAN';
-}
-$Path::Router::Route::Match::VERSION = '0.14';
-use Moose;
+our $AUTHORITY = 'cpan:STEVAN';
+$Path::Router::Route::Match::VERSION = '0.15';
+use Types::Standard  1.000005 qw(Str HashRef InstanceOf);
+
+use Moo              2.000001;
+use namespace::clean 0.23;
 # ABSTRACT: The result of a Path::Router match
 
-has 'path'    => (is => 'ro', isa => 'Str',     required => 1);
-has 'mapping' => (is => 'ro', isa => 'HashRef', required => 1);
+
+has 'path'    => (is => 'ro', isa => Str,     required => 1);
+has 'mapping' => (is => 'ro', isa => HashRef, required => 1);
 
 has 'route'   => (
     is       => 'ro',
-    isa      => 'Path::Router::Route',
+    isa      => InstanceOf['Path::Router::Route'],
     required => 1,
     handles  => [qw[target]]
 );
 
-__PACKAGE__->meta->make_immutable;
-
-no Moose; 1;
+1;
 
 __END__
 
@@ -32,7 +32,7 @@ Path::Router::Route::Match - The result of a Path::Router match
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -77,7 +77,7 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+Stevan Little E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -90,11 +90,11 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
