@@ -1,17 +1,17 @@
 package Path::Router::Shell;
-BEGIN {
-  $Path::Router::Shell::AUTHORITY = 'cpan:STEVAN';
-}
-$Path::Router::Shell::VERSION = '0.14';
-use Moose;
-# ABSTRACT: An interactive shell for testing router configurations
+our $AUTHORITY = 'cpan:STEVAN';
+$Path::Router::Shell::VERSION = '0.15';
+use Term::ReadLine  1.11;
+use Types::Standard 1.000005 qw(InstanceOf);
+use Data::Dumper    2.154;
 
-use Term::ReadLine;
-use Data::Dumper;
+use Moo              2.000001;
+use namespace::clean 0.23;
+# ABSTRACT: An interactive shell for testing router configurations
 
 has 'router' => (
     is       => 'ro',
-    isa      => 'Path::Router',
+    isa      => InstanceOf['Path::Router'],
     required => 1,
 );
 
@@ -36,9 +36,8 @@ sub shell {
     }
 }
 
-__PACKAGE__->meta->make_immutable;
 
-no Moose; 1;
+1;
 
 __END__
 
@@ -52,7 +51,7 @@ Path::Router::Shell - An interactive shell for testing router configurations
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -94,7 +93,7 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+Stevan Little E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -107,11 +106,11 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
